==> wicket-spring-1.4.5-sources.jar: org/apache/wicket/spring/test/SpringContextLocatorMock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.spring.test;

import org.apache.wicket.spring.ISpringContextLocator;
import org.springframework.context.ApplicationContext;


/**
 * Mock SpringContextLocator
 * 
 * @author Igor Vaynberg (ivaynberg)
 * 
 */
public class SpringContextLocatorMock implements ISpringContextLocator
{
	private static final long serialVersionUID = 1L;

	private final ApplicationContext context;

	/**
	 * Constructor
	 * 
	 * @param context
	 */
	public SpringContextLocatorMock(ApplicationContext context)
	{
		this.context = context;
	}

	/**
	 * @see org.apache.wicket.spring.ISpringContextLocator#getSpringContext()
	 */
	public ApplicationContext getSpringContext()
	{
		return context;
	}

}

==> wicket-spring-1.5.13-sources.jar: org/apache/wicket/spring/test/SpringContextLocatorMock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.spring.test;

import org.apache.wicket.spring.ISpringContextLocator;
import org.springframework.context.ApplicationContext;


/**
 * Mock SpringContextLocator
 * 
 * @author Igor Vaynberg (ivaynberg)
 * 
 */
public class SpringContextLocatorMock implements ISpringContextLocator
{
	private static final long serialVersionUID = 1L;

	private final ApplicationContext context;

	/**
	 * Constructor
	 * 
	 * @param context
	 */
	public SpringContextLocatorMock(final ApplicationContext context)
	{
		this.context = context;
	}

	/**
	 * @see org.apache.wicket.spring.ISpringContextLocator#getSpringContext()
	 */
	public ApplicationContext getSpringContext()
	{
		return context;
	}

}
